@@ -8,6 +8,7 @@ from tokenize_rt import Offset
 from tokenize_rt import Token
 
 from pyupgrade._ast_helpers import ast_to_offset
+from pyupgrade._ast_helpers import contains_await
 from pyupgrade._data import register
 from pyupgrade._data import State
 from pyupgrade._data import TokenFunc
@@ -51,7 +52,12 @@ def visit_Call(
             isinstance(node.func, ast.Name) and
             node.func.id in ALLOWED_FUNCS and
             node.args and
-            isinstance(node.args[0], ast.ListComp)
+            isinstance(node.args[0], ast.ListComp) and
+            not any(
+                generator.is_async
+                for generator in node.args[0].generators
+            ) and
+            not contains_await(node.args[0])
     ):
         if len(node.args) == 1 and not node.keywords:
             yield ast_to_offset(node.args[0]), _delete_list_comp_brackets
